@@ -1,5 +1,8 @@
 "Lcomoment.coefficients" <-
 function(Lk,L2) {
+  # L2 is generally to denote a 2nd-order L-comoment matrix EXCEPT
+  # when Lk is first order for L-CV like coefficients.
+
   # Following notation of Serfling and Xiao (2006)
   #  compute the L-comoment coefficients
   #  The univariate L-moment ratios are on the diagonal of Lk
@@ -12,12 +15,20 @@ function(Lk,L2) {
     return()
   }
   if(Lk$order >= 2 && L2$order != 2) {
-    warning("Frist L-comoment matrix is order 2 or greater, but second matrix is not of order 2")
+    warning("First L-comoment matrix is order 2 or greater, but second matrix is not of order 2")
     return()
   }
-  if(Lk$order == 1 && L2Rorder != 1) { # In L-CV calculations L2/L1, but in others Lk/L2
-    warning("First L-comoment matrix is order 1, but second matrix is not 2nd order.")
-    return()
+  if(Lk$order == 1) {
+    if(L2$order != 2) { # In L-CV calculations L2/Lk, where Lk is 1st order,
+                        # but in all others Lk/L2
+      warning("First L-comoment matrix is order 1, but second matrix is not 2nd order.")
+      return()
+    }
+    else {
+      TMP <- Lk # swap Lk and L2 so that a single loop
+      Lk  <- L2 # after this conditional can be used.
+      L2  <- TMP
+    }
   }
   LC      <- Lk$matrix        # to get the structure of Lk
   Lscales <- diag(L2$matrix)  # get univariate L-scale values
