@@ -2,13 +2,13 @@
 function(data) {
    lmom <- lmom.ub(data)
    para <- parpe3(lmom)
-   print("PEARSON TYPE III DISTRIBUTION PARAMETERS")
-   print(para)
+   cat("PEARSON TYPE III DISTRIBUTION PARAMETERS\n")
+   str(para)
    lmompara <- lmompe3(para)
    Q50 <- quape3(0.5,para)
-   print(c('MEDIAN ',Q50))
+   cat(c("Computed median=",Q50,"\n"),sep="")
    P50 <- cdfpe3(Q50,para)
-   print(c('NONEXCEEDANCE OF COMPUTED MEDIAN ',P50))
+   cat(c("Nonexceedance of computed median=",P50,"\n"),sep="")
    lmom.diff(lmompara,lmom)
 }
 
