@@ -1,5 +1,9 @@
 "parTLgld" <-
-function(lmom,result='best',verbose=FALSE,extract=0) {
+function(lmom,result='best',verbose=FALSE,extract=0,initkh=NULL) {
+    if(is.null(lmom$trim)) {
+      warning("An L-moment object and not a TL-moment object appears to have been passed")
+      return()
+    }
     if(length(lmom$trim) == 1 && lmom$trim != 1) {
       warning("Attribute of TL-moments is not trim=1--can not complete parameter estimation")
       return()
@@ -12,6 +16,14 @@ function(lmom,result='best',verbose=FALSE,extract=0) {
     T4 <- lmom$ratios[4]
     T5 <- lmom$ratios[5]
 
+    # Four parameter distributions do not normally need the
+    # fifth L-moment, but for the GLD as implemented here--we do
+    # This error message is to help with this fact.
+    if(is.null(T5)) {
+      warning("The fifth L-moment ratio TAU5 is undefined")
+      return()
+    }
+
     # THE TRIMMED L-MOMENTS OF GLD
     estTLla1 <- function(La2,La3,La4) {
       La1 <- LM1 - 6*La2*(1/((La3+3)*(La3+2)) - 1/((La4+3)*(La4+2)))
@@ -147,21 +159,27 @@ function(lmom,result='best',verbose=FALSE,extract=0) {
       return(TRUE)
     }
 
-   M <- matrix(nrow = 13, ncol = 2)
-   M[1,]  <- c(-2.5,2.5)   # REGION 1
-   M[2,]  <- c(2.5,-2.5)   # REGION 2
-   M[3,]  <- c(2.5,2.5)    # REGION 3
-   M[4,]  <- c(-.5,-.5)    # REGION 4
-   M[5,]  <- c(-1.5,-1.5)  # REGION 4
-   M[6,]  <- c(-2.5,-2.5)  # REGION 4
-   M[7,]  <- c(-3.5,-3.5)  # REGION 4
-   M[8,]  <- c(-4.5,-4.5)  # REGION 4
-   M[9,]  <- c(-5.5,-5.5)  # REGION 4
-   M[10,] <- c(-6.5,-6.5)  # REGION 4
-   M[11,] <- c(-7.5,-7.5)  # REGION 4
-   M[12,] <- c(-.5,2.5)    # REGION 5
-   M[13,] <- c(2.5,-.5)    # REGION 6
-
+   if(is.null(initkh)) {
+     g <- 13
+     M <- matrix(nrow = g, ncol = 2)
+     M[1,]  <- c(-2.5,2.5)   # REGION 1
+     M[2,]  <- c(2.5,-2.5)   # REGION 2
+     M[3,]  <- c(2.5,2.5)    # REGION 3
+     M[4,]  <- c(-.5,-.5)    # REGION 4
+     M[5,]  <- c(-1.5,-1.5)  # REGION 4
+     M[6,]  <- c(-2.5,-2.5)  # REGION 4
+     M[7,]  <- c(-3.5,-3.5)  # REGION 4
+     M[8,]  <- c(-4.5,-4.5)  # REGION 4
+     M[9,]  <- c(-5.5,-5.5)  # REGION 4
+     M[10,] <- c(-6.5,-6.5)  # REGION 4
+     M[11,] <- c(-7.5,-7.5)  # REGION 4
+     M[12,] <- c(-.5,2.5)    # REGION 5
+     M[13,] <- c(2.5,-.5)    # REGION 6
+   }
+   else {
+     M <- matrix(nrow = 1, ncol = 2)
+     M[1,] <- initkh
+   }
    each_count            <- 0
    each_attempt          <- vector(mode = 'numeric', length = 1)
    each_initialK         <- vector(mode = 'numeric', length = 1)
@@ -183,7 +201,7 @@ function(lmom,result='best',verbose=FALSE,extract=0) {
      cat("Attempt      X        A        K        H            TLtau5_diff     SumSqError    Diagnostics\n")
      cat(c(rep("-",WIDTH),"\n"),sep="")
    }
-   for(i in seq(1,13)) {
+   for(i in seq(1,nrow(M))) {
      # Test for NaN from the KEK guess
      if(is.nan(M[i,1]) || is.nan(M[i,2])) next
 
